bf.dist.asymmetric_laplace: Asymmetric Laplace distribution

View source: R/asymmetric_laplace.R

bf.dist.asymmetric_laplaceR Documentation

Asymmetric Laplace distribution

Description

Samples from an Asymmetric Laplace distribution. The Asymmetric Laplace distribution is a generalization of the Laplace distribution, where the two sides of the distribution are scaled differently. It is defined by a location parameter (loc), a scale parameter (scale), and an asymmetry parameter (asymmetry).

f(x, \kappa) = \frac{1}{\kappa+\kappa^{-1}}\exp(-x\kappa),\quad x\ge0

= \frac{1}{\kappa+\kappa^{-1}}\exp(x/\kappa),\quad x<0

\textrm{for } -\infty < x < \infty, \kappa > 0 .

laplace_asymmetric takes 'kappa' as a shape parameter for \kappa. For \kappa = 1, it is identical to a Laplace distribution.

Usage

bf.dist.asymmetric_laplace(
  loc = 0,
  scale = 1,
  asymmetry = 1,
  validate_args = py_none(),
  name = "x",
  obs = py_none(),
  mask = py_none(),
  sample = FALSE,
  seed = py_none(),
  shape = c(),
  event = 0,
  create_obj = FALSE,
  to_jax = TRUE
)

Arguments

loc

A numeric vector or single numeric value representing the location parameter of the distribution. This corresponds to \mu.

scale

A numeric vector or single numeric value representing the scale parameter of the distribution. This corresponds to \sigma.

asymmetry

A numeric vector or single numeric value representing the asymmetry parameter of the distribution. This corresponds to \kappa.

validate_args

Logical: Whether to validate parameter values. Defaults to 'reticulate::py_none()'.

name

A character string representing the name of the random variable within a model. This is used to uniquely identify the variable. Defaults to 'x'.

obs

A numeric vector or array of observed values. If provided, the random variable is conditioned on these values. If 'NULL', the variable is treated as a latent (unobserved) variable. Defaults to 'NULL'.

mask

A logical vector indicating which observations to mask.

sample

A logical value that controls the function's behavior. If 'TRUE', the function will directly draw samples from the distribution. If 'FALSE', it will create a random variable within a model. Defaults to 'FALSE'.

seed

An integer used to set the random seed for reproducibility when 'sample = TRUE'. This argument has no effect when 'sample = FALSE', as randomness is handled by the model's inference engine. Defaults to 0.

shape

A numeric vector specifying the shape of the output. This is used to set the batch shape when sample=FALSE (model building) or as 'sample_shape' to draw a raw JAX array when sample=TRUE (direct sampling).

event

Integer specifying the number of batch dimensions to reinterpret as event dimensions (used in model building).

create_obj

Logical; If 'TRUE', returns the raw BI distribution object instead of creating a sample site.

to_jax

Boolean. Indicates whether to return a JAX array or not.

Value

When sample=FALSE: A BI AsymmetricLaplace distribution object (for model building). When sample=TRUE: A JAX array of samples drawn from the AsymmetricLaplace distribution (for direct sampling). When create_obj=TRUE: The raw BI distribution object (for advanced use cases).

See Also

This is a wrapper of https://num.pyro.ai/en/stable/distributions.html#asymmetriclaplace

Examples


library(BayesForge)
m <- importBF(platform = "cpu")
bf.dist.asymmetric_laplace(sample = TRUE)


BayesForge documentation built on June 9, 2026, 1:09 a.m.