bf.dist.mixture_same_family: A finite mixture of component distributions from the same...

View source: R/mixture_same_family.R

bf.dist.mixture_same_familyR Documentation

A finite mixture of component distributions from the same family.

Description

A *Mixture (Same-Family)* distribution is a finite mixture in which **all components come from the same parametric family** (for example, all Normal distributions but with different parameters), and are combined via mixing weights.

Usage

bf.dist.mixture_same_family(
  mixing_distribution,
  component_distribution,
  validate_args = py_none(),
  name = "x",
  obs = py_none(),
  mask = py_none(),
  sample = FALSE,
  seed = py_none(),
  shape = c(),
  event = 0,
  create_obj = FALSE,
  to_jax = TRUE
)

Arguments

mixing_distribution

A distribution specifying the weights for each mixture component. The size of this distribution specifies the number of components in the mixture.

component_distribution

A list of distributions representing the components of the mixture.

validate_args

Logical: Whether to validate parameter values. Defaults to 'reticulate::py_none()'.

name

A character string representing the name of the random variable within a model. This is used to uniquely identify the variable. Defaults to 'x'.

obs

A numeric vector or array of observed values. If provided, the random variable is conditioned on these values. If 'NULL', the variable is treated as a latent (unobserved) variable. Defaults to 'NULL'.

mask

A logical vector, matrix, or array to mask observations.

sample

A logical value that controls the function's behavior. If 'TRUE', the function will directly draw samples from the distribution. If 'FALSE', it will create a random variable within a model. Defaults to 'FALSE'.

seed

An integer used to set the random seed for reproducibility when 'sample = TRUE'. This argument has no effect when 'sample = FALSE', as randomness is handled by the model's inference engine. Defaults to 0.

shape

A numeric vector specifying the shape of the distribution.

event

Integer representing the number of batch dimensions to reinterpret as event dimensions (used in model building).

create_obj

Logical; If TRUE, returns the raw BI distribution object instead of creating a sample site.

to_jax

Boolean. Indicates whether to return a JAX array or not.

Value

- When sample=FALSE, a BI MixtureSameFamily distribution object (for model building).

- When sample=TRUE, a JAX array of samples drawn from the MixtureSameFamily distribution (for direct sampling).

- When create_obj=TRUE, the raw BI distribution object (for advanced use cases).

See Also

This is a wrapper of https://num.pyro.ai/en/stable/distributions.html#mixture-same-family

Examples


library(BayesForge)
m <- importBF(platform = "cpu")
bf.dist.mixture_same_family(
  mixing_distribution = bf.dist.categorical(probs = c(0.3, 0.7), create_obj = TRUE),
  component_distribution = bf.dist.normal(0, 1, shape = c(2), create_obj = TRUE),
  sample = TRUE
)


BayesForge documentation built on June 9, 2026, 1:09 a.m.