install_dependencies: Install dependencies

View source: R/BF_management.R

install_dependenciesR Documentation

Install dependencies

Description

Install dependencies

Usage

install_dependencies(envname = "BFR")

Arguments

envname

A character string specifying the name of the virtual environment.

Details

Internal helper function to install dependencies for the 'BayesForge' package.

Value

No return value, called for side effects (installs Python packages into the specified virtual environment).


BayesForge documentation built on June 9, 2026, 1:09 a.m.