View source: R/BF_management.R
| list_packages | R Documentation |
List packages in a virtual environment
list_packages(envname = "BFR")
envname |
A character string specifying the name of the virtual environment. |
Internal helper function to list packages in a virtual environment.
A data frame with columns package and version listing
the Python packages installed in the specified virtual environment.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.