setup_env: Create a Python virtual environment

View source: R/BF_management.R

setup_envR Documentation

Create a Python virtual environment

Description

This function creates a Python virtual environment using reticulate.

Usage

setup_env(env_name = "BFR", backend = "cpu")

Arguments

env_name

A character string for the name of the virtual environment. Defaults to "BFR-cpu" or "BFR-gpu".

backend

A character string specifying the backend, either "cpu" or "gpu".

Value

The path to the created virtual environment. Create a Python virtual environment and install dependencies

This function creates a Python virtual environment and installs a specified set of Python packages, with options for CPU or GPU builds.

The path to the created virtual environment.


BayesForge documentation built on June 9, 2026, 1:09 a.m.