| bf.dist.geometric | R Documentation |
Samples from a Geometric distribution, which models the number of failures before the first success in a sequence of independent Bernoulli trials. It is parameterized by logits, which are transformed into probabilities using the sigmoid function.
bf.dist.geometric(
probs = py_none(),
logits = py_none(),
validate_args = py_none(),
name = "x",
obs = py_none(),
mask = py_none(),
sample = FALSE,
seed = py_none(),
shape = c(),
event = 0,
create_obj = FALSE,
to_jax = TRUE
)
probs |
A numeric vector, matrix, or array representing the probability of success on each trial. Must be between 0 and 1. |
logits |
A numeric vector, matrix, or array representing the log-odds of success on each trial. 'probs = jax.nn.sigmoid(logits)'. |
validate_args |
Logical: Whether to validate parameter values. Defaults to 'reticulate::py_none()'. |
name |
A character string representing the name of the random variable within a model. This is used to uniquely identify the variable. Defaults to 'x'. |
obs |
A numeric vector or array of observed values. If provided, the random variable is conditioned on these values. If 'NULL', the variable is treated as a latent (unobserved) variable. Defaults to 'NULL'. |
mask |
A logical vector, matrix, or array to mask observations. |
sample |
A logical value that controls the function's behavior. If 'TRUE', the function will directly draw samples from the distribution. If 'FALSE', it will create a random variable within a model. Defaults to 'FALSE'. |
seed |
An integer used to set the random seed for reproducibility when 'sample = TRUE'. This argument has no effect when 'sample = FALSE', as randomness is handled by the model's inference engine. Defaults to 0. |
shape |
A numeric vector specifying the shape of the output. Used to set the distribution's batch shape when |
event |
An integer representing the number of batch dimensions to reinterpret as event dimensions (used in model building). |
create_obj |
A logical value. If 'TRUE', returns the raw BI distribution object instead of creating a sample site. |
to_jax |
Boolean. Indicates whether to return a JAX array or not. |
When sample=FALSE: A BI Geometric distribution object (for model building).
When sample=TRUE: A JAX array of samples drawn from the Geometric distribution (for direct sampling).
When create_obj=TRUE: The raw BI distribution object (for advanced use cases).
This is a wrapper of https://num.pyro.ai/en/stable/distributions.html#geometric
library(BayesForge)
m=importBF(platform='cpu')
bf.dist.geometric(logits = 0.5, sample = TRUE)
bf.dist.geometric(probs = 0.5, sample = TRUE)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.