| bf.dist.log_uniform | R Documentation |
A random variable $X$ is **log-uniform** on
[a, b]
, with $0 < a < b$, if
\ln X
is uniformly distributed on
[\ln a, \ln b]
. Equivalently, the density of $X$ is proportional to $1/x$ over that interval. This distribution is sometimes called the *reciprocal distribution*. It is useful in modeling scales spanning several orders of magnitude, where you want every decade (or log-interval) to have equal weight.
bf.dist.log_uniform(
low,
high,
validate_args = py_none(),
name = "x",
obs = py_none(),
mask = py_none(),
sample = FALSE,
seed = py_none(),
shape = c(),
event = 0,
create_obj = FALSE,
to_jax = TRUE
)
low |
A numeric vector representing the lower bound of the uniform distribution's log-space. Must be positive. |
high |
A numeric vector representing the upper bound of the uniform distribution's log-space. Must be positive. |
validate_args |
Logical: Whether to validate parameter values. Defaults to 'reticulate::py_none()'. |
name |
A character string representing the name of the random variable within a model. This is used to uniquely identify the variable. Defaults to 'x'. |
obs |
A numeric vector or array of observed values. If provided, the random variable is conditioned on these values. If 'NULL', the variable is treated as a latent (unobserved) variable. Defaults to 'NULL'. |
mask |
A logical vector to mask observations. |
sample |
A logical value that controls the function's behavior. If 'TRUE', the function will directly draw samples from the distribution. If 'FALSE', it will create a random variable within a model. Defaults to 'FALSE'. |
seed |
An integer used to set the random seed for reproducibility when 'sample = TRUE'. This argument has no effect when 'sample = FALSE', as randomness is handled by the model's inference engine. Defaults to 0. |
shape |
A numeric vector specifying the shape of the output. When |
event |
Integer specifying the number of batch dimensions to reinterpret as event dimensions (used in model building). |
create_obj |
Logical; If TRUE, returns the raw BI distribution object instead of creating a sample site. |
to_jax |
Boolean. Indicates whether to return a JAX array or not. |
- When sample=FALSE, a BI Log Uniform distribution object (for model building).
- When sample=TRUE, a JAX array of samples drawn from the Log Uniform distribution (for direct sampling).
- When create_obj=TRUE, the raw BI distribution object (for advanced use cases).
This is a wrapper of https://num.pyro.ai/en/stable/distributions.html#loguniform
library(BayesForge)
m=importBF(platform='cpu')
bf.dist.log_uniform(1,2, sample = TRUE)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.