View source: R/truncated_distribution.R
| bf.dist.truncated_distribution | R Documentation |
A **truncated distribution** arises when you take a random variable
X
that originally has some distribution (with PDF
f_X(x)
and CDF
F_X(x)
) and you restrict attention only to those values of
X
that are *above* a given truncation point
a
. In other words you only observe $X$ when $X > a$. All the "mass" below (or equal to)
a
is **excluded** (not just unobserved, but removed from the sample/analysis). This differs from *censoring*, where values below a threshold might be known (for example "< a"), but here they are entirely excluded from the domain. Left truncation is common in many applied fields.
bf.dist.truncated_distribution(
base_dist,
low = py_none(),
high = py_none(),
validate_args = py_none(),
name = "x",
obs = py_none(),
mask = py_none(),
sample = FALSE,
seed = py_none(),
shape = c(),
event = 0,
create_obj = FALSE,
to_jax = TRUE
)
base_dist |
The base distribution to be truncated. This should be a univariate distribution. Currently, only the following distributions are supported: Cauchy, Laplace, Logistic, Normal, and StudentT. |
low |
(float, jnp.ndarray, optional): The lower truncation point. If 'None', the distribution is only truncated on the right. Defaults to 'None'. |
high |
(float, jnp.ndarray, optional): The upper truncation point. If 'None', the distribution is only truncated on the left. Defaults to 'None'. |
validate_args |
Logical: Whether to validate parameter values. Defaults to 'reticulate::py_none()'. |
name |
A character string representing the name of the random variable within a model. This is used to uniquely identify the variable. Defaults to 'x'. |
obs |
A numeric vector or array of observed values. If provided, the random variable is conditioned on these values. If 'NULL', the variable is treated as a latent (unobserved) variable. Defaults to 'NULL'. |
mask |
An optional boolean array to mask observations. |
sample |
A logical value that controls the function's behavior. If 'TRUE', the function will directly draw samples from the distribution. If 'FALSE', it will create a random variable within a model. Defaults to 'FALSE'. |
seed |
An integer used to set the random seed for reproducibility when 'sample = TRUE'. This argument has no effect when 'sample = FALSE', as randomness is handled by the model's inference engine. Defaults to 0. |
shape |
A numeric vector (e.g., 'c(10)') specifying the shape. When |
event |
The number of batch dimensions to reinterpret as event dimensions (used in model building). |
create_obj |
Logical; If 'TRUE', returns the raw BI distribution object instead of creating a sample site. This is essential for building complex distributions like 'MixtureSameFamily'. |
to_jax |
Boolean. Indicates whether to return a JAX array or not. |
- When sample=FALSE, a BI Truncated distribution object (for model building).
- When sample=TRUE, a JAX array of samples drawn from the Truncated distribution (for direct sampling).
- When create_obj=TRUE, the raw BI distribution object (for advanced use cases).
https://num.pyro.ai/en/stable/distributions.html#truncateddistribution
library(BayesForge)
m=importBF(platform='cpu')
bf.dist.truncated_distribution(
base_dist = bf.dist.normal(0,1, create_obj = TRUE),
high = 0.7,
low = 0.1,
sample = TRUE)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.