View source: R/truncated_normal.R
| bf.dist.truncated_normal | R Documentation |
A truncated normal distribution is derived from a normal (Gaussian) random variable by restricting (truncating) its domain to an interval
[a, b]
(which could be one-sided, e.g., (a) only or (b) only). It is defined by its location ('loc'), scale ('scale'), lower bound
a
('low'), and upper bound
b
('high'). In effect: if
X \sim \mathcal N(\mu, \sigma^2)
, then the truncated version
Y = X | (a \le X \le b)
has the same "shape" but only supports values in
[a,b]
. This is used when you know that values outside a range are impossible or not observed (e.g., measurement limits, natural bounds).
bf.dist.truncated_normal(
loc = 0,
scale = 1,
low = py_none(),
high = py_none(),
validate_args = py_none(),
name = "x",
obs = py_none(),
mask = py_none(),
sample = FALSE,
seed = py_none(),
shape = c(),
event = 0,
create_obj = FALSE,
to_jax = TRUE
)
loc |
The location parameter of the normal distribution. |
scale |
The scale parameter of the normal distribution. |
low |
(float, jnp.ndarray, optional): The lower truncation point. If 'None', the distribution is only truncated on the right. Defaults to 'None'. |
high |
(float, jnp.ndarray, optional): The upper truncation point. If 'None', the distribution is only truncated on the left. Defaults to 'None'. |
validate_args |
Logical: Whether to validate parameter values. Defaults to 'reticulate::py_none()'. |
name |
A character string representing the name of the random variable within a model. This is used to uniquely identify the variable. Defaults to 'x'. |
obs |
A numeric vector or array of observed values. If provided, the random variable is conditioned on these values. If 'NULL', the variable is treated as a latent (unobserved) variable. Defaults to 'NULL'. |
mask |
An optional boolean array to mask observations. |
sample |
A logical value that controls the function's behavior. If 'TRUE', the function will directly draw samples from the distribution. If 'FALSE', it will create a random variable within a model. Defaults to 'FALSE'. |
seed |
An integer used to set the random seed for reproducibility when 'sample = TRUE'. This argument has no effect when 'sample = FALSE', as randomness is handled by the model's inference engine. Defaults to 0. |
shape |
A numeric vector (e.g., 'c(10)') used to shape the distribution. When 'sample=False' (model building), this is used with '.expand(shape)' to set the distribution's batch shape. When 'sample=True' (direct sampling), this is used as 'sample_shape' to draw a raw JAX array of the given shape. |
event |
The number of batch dimensions to reinterpret as event dimensions (used in model building). |
create_obj |
Logical; If 'TRUE', returns the raw BI distribution object instead of creating a sample site. |
to_jax |
Boolean. Indicates whether to return a JAX array or not. |
- When sample=FALSE, a BI Truncated Normal distribution object (for model building).
- When sample=TRUE, a JAX array of samples drawn from the Truncated Normal distribution (for direct sampling).
- When create_obj=TRUE, the raw BI distribution object (for advanced use cases).
library(BayesForge)
m=importBF(platform='cpu')
bf.dist.truncated_normal(loc = 0, scale = 2, low = 0, high = 1.5, sample = TRUE)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.