View source: R/BF_management.R
| install_dependencies | R Documentation |
Install dependencies
install_dependencies(envname = "BFR")
envname |
A character string specifying the name of the virtual environment. |
Internal helper function to install dependencies for the 'BayesForge' package.
No return value, called for side effects (installs Python packages into the specified virtual environment).
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.