View source: R/BF_management.R
| setup_env | R Documentation |
This function creates a Python virtual environment using reticulate.
setup_env(env_name = "BFR", backend = "cpu")
env_name |
A character string for the name of the virtual environment. Defaults to "BFR-cpu" or "BFR-gpu". |
backend |
A character string specifying the backend, either "cpu" or "gpu". |
The path to the created virtual environment. Create a Python virtual environment and install dependencies
This function creates a Python virtual environment and installs a specified set of Python packages, with options for CPU or GPU builds.
The path to the created virtual environment.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.